#!/usr/bin/env python2
"""WSDL parsing services package for Web Services for Python."""

ident = "$Id$"

from . import WSDLTools
from . import XMLname
